// -*- javascript -*-
// https://wiki.alioth.net/index.php/Oolite_JavaScript_Reference:_World_script_event_handlers
//
// Inspired by discussion at https://bb.oolite.space/viewtopic.php?p=284994#p284994
// Original source released to public domain by 'hulo'

"use strict";

this.name        = "oolite.oxp.mils32k.EnergyContainmentUnit:ShieldBoostersECU";
this.author      = "mlewissmith";
this.copyright   = "(C) 2024 mlewissmith";
this.licence     = "UNLICENSE";
this.description = "Energy Containment Unit enhancements to Standard Equipment available to buy.";
this.version     = "0.2.2";

////////////////////////////////////////////////////////////////////////////////
// Debuggery

this.$debug_enabled = false;
this._log           = function(log_message) { log(this.name, log_message) }
this._debug         = function(debug_message) { if (this.$debug_enabled) this._log(debug_message) }

////////////////////////////////////////////////////////////////////////////////
// Internals

this.$active = false;

this._activateECU = function() {
    if ( !this.$active ) {
        this.$active = true;
        this._debug( "_activateECU()" );
        player.consoleMessage("Shield Boosters ECU: activated");
    }
}

this._deactivateECU = function() {
    if ( this.$active ) {
        this.$active = false;
        this._debug( "_deactivateECU()" );
        player.consoleMessage("Shield Boosters ECU: deactivated");
    }
}

this._loseLicence = function() {
    player.ship.removeEquipment("EQ_ECU_SHIELDBOOSTERS_LICENCE");
}

this._expireActiveLicence = function() {
    if ( this.$active ) {
        this._deactivateECU();
        this._loseLicence();
        player.consoleMessage("Shield Boosters ECU: licence expired");
    }
}

this._handleECU = function() {
    if ( this.$active ) {
        player.ship.aftShield     = player.ship.maxAftShield;
        player.ship.forwardShield = player.ship.maxForwardShield;
    }
}

////////////////////////////////////////////////////////////////////////////////
// Event handlers : startup

this.startUp = function() {
    this._debug( "startUp()" );
    this._debug( "name        : " + this.name );
    this._debug( "author      : " + this.author );
    this._debug( "copyright   : " + this.copyright );
    this._debug( "license     : " + this.license );
    this._debug( "description : " + this.description );
    this._debug( "version     : " + this.version );
}

this.startUpComplete = function() {
    this._debug( "startUpComplete()" );
}

////////////////////////////////////////////////////////////////////////////////
// Event handlers : combat

this.shipBeingAttacked = function(whom) {
    this._handleECU()
}

this.shipBeingAttackedByCloaked = function() {
    this._handleECU()
}

////////////////////////////////////////////////////////////////////////////////
// Event handlers : end-of-flight

this.shipWillDockWithStation = function(station) {
    this._expireActiveLicence();
}

this.shipWillEnterWitchspace = function(cause, destination) { // API 1.81
    this._expireActiveLicence();
}

////////////////////////////////////////////////////////////////////////////////
// Event handlers : equipment add/remove

this.equipmentAdded = function(equipmentKey) { // API 1.81
    this._debug( "equipmentAdded(" + equipmentKey + ")" );
}

this.equipmentDamaged = function(equipmentKey) {
    this._debug( "equipmentDamaged(" + equipmentKey + ")" );

    if (equipmentKey == "EQ_SHIELD_BOOSTER") {
        player.ship.setEquipmentStatus("EQ_ECU_SHIELDBOOSTERS", "EQUIPMENT_DAMAGED");
    }

    if (equipmentKey == "EQ_ECU_SHIELDBOOSTERS") {
        this._expireActiveLicence();
        this._loseLicence();
    }
}

this.equipmentRemoved = function(equipmentKey) { // API 1.81
    this._debug( "equipmentRemoved(" + equipmentKey + ")" );
}

this.playerBoughtEquipment = function(equipment, paid) { // API 1.89
    this._debug( "playerBoughtEquipment(" + equipment + "," + paid + ")" );

    if (equipment == "EQ_ECU_SHIELDBOOSTERS_REMOVAL") {
        var credits = EquipmentInfo.infoForKey("EQ_ECU_SHIELDBOOSTERS").price * 0.1;
        var refundPc = 0.6;
        var refundCredits = credits * refundPc;

        this._loseLicence();
        player.ship.removeEquipment("EQ_ECU_SHIELDBOOSTERS");
        player.ship.removeEquipment("EQ_ECU_SHIELDBOOSTERS_REMOVAL");
        player.credits += refundCredits;
    }
}
